summaryrefslogtreecommitdiffstats
path: root/src/server/LV2Plugin.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/LV2Plugin.hpp')
-rw-r--r--src/server/LV2Plugin.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/server/LV2Plugin.hpp b/src/server/LV2Plugin.hpp
index e4360398..127300cf 100644
--- a/src/server/LV2Plugin.hpp
+++ b/src/server/LV2Plugin.hpp
@@ -20,8 +20,8 @@
#include "ingen-config.h"
#ifndef HAVE_SLV2
#error "This file requires SLV2, but HAVE_SLV2 is not defined. Please report."
#endif
#include <cstdlib>
@@ -30,7 +30,7 @@
#include <glibmm/module.h>
#include <boost/utility.hpp>
-#include "slv2/slv2.h"
+#include "lilv/lilv.h"
#include "raul/SharedPtr.hpp"
#include "PluginImpl.hpp"
@@ -61,11 +61,11 @@ public:
const std::string& library_path() const;
- SLV2Plugin slv2_plugin() const { return _slv2_plugin; }
- void slv2_plugin(SLV2Plugin p);
+ LilvPlugin lilv_plugin() const { return _lilv_plugin; }
+ void lilv_plugin(LilvPlugin p);
private:
- SLV2Plugin _slv2_plugin;
+ LilvPlugin _lilv_plugin;
SharedPtr<LV2Info> _lv2_info;
};
@@ -20,8 +20,8 @@
#include "ingen-config.h"
-#ifndef HAVE_SLV2
-#error "This file requires SLV2, but HAVE_SLV2 is not defined. Please report."
+#ifndef HAVE_LILV
+#error "This file requires Lilv, but HAVE_LILV is not defined. Please report."
#endif
#include <cstdlib>